==> tabular-data-gwt-service-2.5.1-20141210.173820-2.jar: org/gcube/portlets/user/td/gwtservice/shared/extract/ExtractCodelistTargetColumn.java <==
package org.gcube.portlets.user.td.gwtservice.shared.extract;

import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.gwtservice.shared.tr.DefNewColumn;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

/**
 * 
 * @author "Giancarlo Panichi"
 * 
 */
public class ExtractCodelistTargetColumn implements Serializable {

	private static final long serialVersionUID = -3223334571168535567L;

	protected boolean newColumn;
	protected ColumnData sourceColumn;
	protected ColumnData targetColumn;
	protected TRId codelist;
	protected DefNewColumn defColumn;

	public ExtractCodelistTargetColumn() {

	}

	public ExtractCodelistTargetColumn(ColumnData sourceColumn,
			ColumnData targetColumn, TRId codelist) {
		this.newColumn = false;
		this.sourceColumn = sourceColumn;
		this.targetColumn = targetColumn;
		this.codelist = codelist;
	}

	public ExtractCodelistTargetColumn(ColumnData sourceColumn, DefNewColumn defNewColumn) {
		this.newColumn = true;
		this.sourceColumn = sourceColumn;
		this.defColumn=defNewColumn;
	}

	public boolean isNewColumn() {
		return newColumn;
	}

	public void setNewColumn(boolean newColumn) {
		this.newColumn = newColumn;
	}

	public ColumnData getSourceColumn() {
		return sourceColumn;
	}

	public void setSourceColumn(ColumnData sourceColumn) {
		this.sourceColumn = sourceColumn;
	}

	public ColumnData getTargetColumn() {
		return targetColumn;
	}

	public void setTargetColumn(ColumnData targetColumn) {
		this.targetColumn = targetColumn;
	}

	public TRId getCodelist() {
		return codelist;
	}

	public void setCodelist(TRId codelist) {
		this.codelist = codelist;
	}

	public DefNewColumn getDefColumn() {
		return defColumn;
	}

	public void setDefColumn(DefNewColumn defColumn) {
		this.defColumn = defColumn;
	}

	@Override
	public String toString() {
		return "ExtractCodelistTargetColumn [newColumn=" + newColumn
				+ ", sourceColumn=" + sourceColumn + ", targetColumn="
				+ targetColumn + ", codelist=" + codelist + ", defColumn="
				+ defColumn + "]";
	}

	
	

}

==> tabular-data-gwt-service-2.9.0-20160120.133042-48.jar: org/gcube/portlets/user/td/gwtservice/shared/extract/ExtractCodelistTargetColumn.java <==
package org.gcube.portlets.user.td.gwtservice.shared.extract;

import java.io.Serializable;

import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnMockUp;

/**
 * 
 * @author "Giancarlo Panichi"
 * 
 */
public class ExtractCodelistTargetColumn implements Serializable {

	private static final long serialVersionUID = -3223334571168535567L;

	protected boolean newColumn;
	protected ColumnData sourceColumn;
	protected ColumnData targetColumn;
	protected TRId codelist;
	protected ColumnMockUp defColumn;

	public ExtractCodelistTargetColumn() {

	}

	public ExtractCodelistTargetColumn(ColumnData sourceColumn,
			ColumnData targetColumn, TRId codelist) {
		this.newColumn = false;
		this.sourceColumn = sourceColumn;
		this.targetColumn = targetColumn;
		this.codelist = codelist;
	}

	public ExtractCodelistTargetColumn(ColumnData sourceColumn, ColumnMockUp defNewColumn) {
		this.newColumn = true;
		this.sourceColumn = sourceColumn;
		this.defColumn=defNewColumn;
	}

	public boolean isNewColumn() {
		return newColumn;
	}

	public void setNewColumn(boolean newColumn) {
		this.newColumn = newColumn;
	}

	public ColumnData getSourceColumn() {
		return sourceColumn;
	}

	public void setSourceColumn(ColumnData sourceColumn) {
		this.sourceColumn = sourceColumn;
	}

	public ColumnData getTargetColumn() {
		return targetColumn;
	}

	public void setTargetColumn(ColumnData targetColumn) {
		this.targetColumn = targetColumn;
	}

	public TRId getCodelist() {
		return codelist;
	}

	public void setCodelist(TRId codelist) {
		this.codelist = codelist;
	}

	public ColumnMockUp getDefColumn() {
		return defColumn;
	}

	public void setDefColumn(ColumnMockUp defColumn) {
		this.defColumn = defColumn;
	}

	@Override
	public String toString() {
		return "ExtractCodelistTargetColumn [newColumn=" + newColumn
				+ ", sourceColumn=" + sourceColumn + ", targetColumn="
				+ targetColumn + ", codelist=" + codelist + ", defColumn="
				+ defColumn + "]";
	}

	
	

}
